# Copyright David Abrahams 2004. Distributed under the Boost
# Software License, Version 1.0. (See accompanying
# file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
import sys
if (sys.version_info.major >= 3):
    long = int
'''
>>> from long_ext import *
>>> print(new_long())
0
>>> print(longify(42))
42
>>> print(longify_string('300'))
300
>>> is_long(long(20))
'yes'
>>> is_long('20')
0

>>> x = Y(long(4294967295))
'''

def run(args = None):
    import sys
    import doctest

    if args is not None:
        sys.argv = args
    return doctest.testmod(sys.modules.get(__name__))

if __name__ == '__main__':
    print("running...")
    import sys
    status = run()[0]
    if (status == 0): print("Done.")
    sys.exit(status)




# Copyright (C) 2009-2012 Lorenzo Caminiti
# Distributed under the Boost Software License, Version 1.0
# (see accompanying file LICENSE_1_0.txt or a copy at
# http://www.boost.org/LICENSE_1_0.txt)
# Home at http://www.boost.org/libs/local_function

import sys
import time
import os

if len(sys.argv) < 2:
    print "Usage: python " + sys.argv[0] + " COMMAND [COMMAND_OPTIONS]"
    print "Measure run-time of executing the specified command."
    exit(1)

cmd = ""
for arg in sys.argv[1:]: cmd += str(arg) + " "

start = time.time()
ret = os.system(cmd)
sec = time.time() - start

if (ret == 0): print "\n" + str(sec) + "s"




#!/usr/bin/env python

# Copyright Jim Bosch & Ankit Daftery 2010-2012.
# Distributed under the Boost Software License, Version 1.0.
#    (See accompanying file LICENSE_1_0.txt or copy at
#          http://www.boost.org/LICENSE_1_0.txt)

import templates_ext
import unittest
import numpy

class TestTemplates(unittest.TestCase):

    def testTemplates(self):
        for dtype in (numpy.int16, numpy.int32, numpy.float32, numpy.complex128):
            v = numpy.arange(12, dtype=dtype)
            for shape in ((12,), (4, 3), (2, 6)):
                a1 = numpy.zeros(shape, dtype=dtype)
                a2 = v.reshape(a1.shape)
                templates_ext.fill(a1)
                self.assert_((a1 == a2).all())
        a1 = numpy.zeros((12,), dtype=numpy.float64)
        self.assertRaises(TypeError, templates_ext.fill, a1)
        a1 = numpy.zeros((12,2,3), dtype=numpy.float32)
        self.assertRaises(TypeError, templates_ext.fill, a1)

if __name__=="__main__":
    unittest.main()
